@@ -8,6 +8,9 @@
 
 "use strict";
 
+var { TbSync } = ChromeUtils.import("chrome://tbsync/content/tbsync.jsm");
+var { MailServices } = ChromeUtils.import("resource:///modules/MailServices.jsm");
+
 // Every object in here will be loaded into TbSync.providers.<providername>.
 const eas = TbSync.providers.eas;
 
@@ -280,7 +283,7 @@ var Base = class {
             "synckey" : "",
             "target" : "",
             "targetColor" : "",
-            "targetName" : "",            
+            "targetName" : "",
             "parentID" : "0",
             "serverID" : "",
             };
@@ -526,7 +529,8 @@ var TargetData_addressbook = class extends TbSync.addressbook.AdvancedTargetData
         
         if (directory && directory instanceof Components.interfaces.nsIAbDirectory && directory.dirPrefId == dirPrefId) {
             directory.setStringValue("tbSyncIcon", "eas" + (this.folderData.accountData.getAccountProperty("servertype") == "office365" ? "_365" : ""));
-            return directory;		
+            directory.setStringValue("tbSyncRevision", "2");
+            return directory;
         }
         return null;
     }
